%
% Gregory MacCabe
% 05/2017
% mK Optomechanics experiments summary of key figures of merit
%


%% Natural constants

c = 299792458; % m/s
hbar = 1.055*10^-34; % kg m^2 / s
kB=1.38064852e-23; % J/K
 
%% Device parameters

% optics
lambda = 1538.9708e-9; % m
omegac = 2*pi*c/lambda; % rad/s
Qi = 3.51e5;
etaKappa = 0.228;
Qt = (1-etaKappa)*Qi;
Qe = etaKappa*Qt;

kappa = omegac/(2*pi*Qt);
kappai = omegac/(2*pi*Qi);
kappaE = omegac/(2*pi*Qe);

% mechanics
fm = 5.3124555e9; % Hz
omegaM = 2*pi*fm; % rad/s

Qm = 104e6;
gamma0 = fm/Qm;
gammai = 50e3; % time-averaged mechanical linewidth (broadened due to frequency jitter)

T0 = 0.035; % K, base thermalization temperature
n0 = (exp(hbar*omegaM/(kB*T0))-1)^-1;

% optomechanical coupling
g0 = 7.50e5; % Hz

%% Setup parameters

% === sideband filters (267W optical table, inside insulated housing) ===
fpFSR = [2.064e10, 1.864e10, 9.99e9]; % Hz
fpBW = [5.56e7, 4.56e7, 4.56e7]; % Hz
fpInsLoss = [3.6, 3.6, 4.0]; % dB

% xx = [f, FSR, BW, insertion loss]
fpTransfer = @(xx) 10.^(-xx(4)/10).*( ((xx(3)/2)^2)./(xx(1).^2 + (xx(3)/2)^2) + ...
                                      ((xx(3)/2)^2)./((xx(1) - xx(2)).^2 + (xx(3)/2)^2) + ...
                                      ((xx(3)/2)^2)./((xx(1) + xx(2)).^2 + (xx(3)/2)^2) + ...
                                      ((xx(3)/2)^2)./((xx(1) - 2*xx(2)).^2 + (xx(3)/2)^2) + ...
                                      ((xx(3)/2)^2)./((xx(1) + 2*xx(2)).^2 + (xx(3)/2)^2) + ...
                                      ((xx(3)/2)^2)./((xx(1) - 3*xx(2)).^2 + (xx(3)/2)^2) + ...
                                      ((xx(3)/2)^2)./((xx(1) + 3*xx(2)).^2 + (xx(3)/2)^2) );

% plot transfer functions
FF = 1e4;
fpDomain = linspace(-fpFSR(1), +fpFSR(1), FF);
fp1Transfer = zeros(1,FF);
fp2Transfer = zeros(1,FF);
fp3Transfer = zeros(1,FF);
for k = 1:FF;
    fp1Transfer(k) = fpTransfer([fpDomain(k), fpFSR(1), fpBW(1), fpInsLoss(1)]);
    fp2Transfer(k) = fpTransfer([fpDomain(k), fpFSR(2), fpBW(2), fpInsLoss(2)]);
    fp3Transfer(k) = fpTransfer([fpDomain(k), fpFSR(3), fpBW(3), fpInsLoss(3)]);
end

fpTotalTransfer = fp1Transfer.*fp2Transfer.*fp3Transfer; % if fm ~ fpFSR(3), do not use filter 3.
A = fpTransfer([fm, fpFSR(1), fpBW(1), fpInsLoss(1)])*fpTransfer([fm, fpFSR(2), fpBW(2), fpInsLoss(2)])*fpTransfer([fm, fpFSR(3), fpBW(3), fpInsLoss(3)]); % insertion loss to filter stack

figure();
semilogy(fpDomain, fpTotalTransfer, 'LineWidth', 2, 'Color', 'r');
hold on;
semilogy(fpDomain, fp1Transfer, 'LineWidth', 1, 'Color', 'm');
semilogy(fpDomain, fp2Transfer, 'LineWidth', 1, 'Color', 'c');
semilogy(fpDomain, fp3Transfer, 'LineWidth', 1, 'Color', 'k');
legend('Total','Filter 1','Filter 2','Filter 3');
xlabel('Frequency (Hz)'); ylabel('F-P stack transfer function');
hold off


% === high-extinction === 
Ag1ER = 15; % dB
Ag2ER = 20.7; % dB
EOM1ER = 29; % dB
EOM2ER = 30; % dB
ExtRatio = Ag1ER+Ag2ER+EOM1ER+EOM2ER;
AOMER = 57; % dB (needs to be measured)

% === efficiencies ===
eta12 = 0.775; % circulator 1->2
eta23 = 0.775; % circulator 2->3
etaCpl = 0.326; % fiber-waveguide coupling
eta2F = 0.88; % circulator 2->top of fridge via Ch C fiber
etaDet = 0.043; % from circulator port 3 to top of fridge for SPD run (includes sideband filter stack)
etaSPD = 0.50; % SPD efficiency, including entire fiber run inside fridge
eta = etaKappa*etaCpl*etaDet*etaSPD; % total detection rate of cavity photons

DCR = 0.8; % c.p.s., Best SPD dark-count rate

%% Measurement details

%% Analysis outlines

DET = +1; % +1 for red-detuned, -1 for blue-detuned
numNC = 1e4;
ncArr = logspace(-6,4,numNC);
gammaOM = (4*g0^2/kappa).*ncArr; % array on entire nc domain
gammaOMhandle = @(ncxx) (4*g0^2/kappa).*ncxx;
gammaSB0 = 2*pi*eta*gammaOM % c.p.s.
gammaSB0handle = @(ncxx) 2*pi*eta*(4*g0^2/kappa)*ncxx;
figure();
loglog(ncArr, gammaSB0);
xlim([min(ncArr) max(ncArr)]);
xlabel('n_c (photons)'); ylabel('\Gamma_{SB,0} (c.p.s.)');

% sensitivity
darkNoiseTerm = DCR./(eta*gammaOM); % c.p.s.
bleedThruNoiseTerm = A*(kappa*fm/(2*kappaE*g0)).^2; % c.p.s.
nNEP = darkNoiseTerm + bleedThruNoiseTerm;

figure();
loglog(ncArr, nNEP, 'LineWidth', 2, 'Color', 'k');
hold on;
loglog(ncArr, darkNoiseTerm, 'LineWidth', 1, 'Color', 'b');
xlim([min(ncArr) max(ncArr)]);
loglog(ncArr, bleedThruNoiseTerm*ones(1,length(ncArr)), 'LineWidth', 1, 'Color', 'g');
xlabel('n_c (photons)'); ylabel('n_{NEP}');
legend('n_{NEP}', 'DCR noise', 'Pump noise');
hold off;


%% Bath properties

alphaGamma = 3/8;
alphanP = 1/2;

gammaP = 2.16e3*ncArr.^(alphaGamma); % Hz
gammaPhandle = @(ncxx) 31*ncxx^(alphaGamma);
nP = (2.05)*ncArr.^(alphanP); 
nPhandle = @(ncxx) 6.69*ncxx^(alphanP);

gammaS = 5.0e5; % Hz, slow bath turn-on rate
deltab = 0.80; % 0 < deltab < 1, fast bath fraction

figure();
yyaxis left
plot(ncArr, gammaP);
ylabel('\gamma_P/2\pi (Hz)');
set(gca,'YScale','log');
yyaxis right
plot(ncArr, nP);
ylabel('n_P');
set(gca,'YScale','log');
set(gca,'XScale','log');
xlabel('n_c (photons)');
xlim([min(ncArr) max(ncArr)]);


%% Cooperativity and cooling estimates

% sideband resolution paramter
SBRes = (fm/(4*kappa))^2;

% effective cooperativity
Ceff = gammaOM./(gammaP.*(nP+1) + gamma0.*(n0+1));

% steady-state phonon occupancy
nbarSS = (gammaP.*(nP+1) + gamma0.*(n0+1) + 0.5*(1 - DET)*gammaOM)./(gammaOM + gammaP + gamma0);

figure();
yyaxis left
plot(ncArr, Ceff);
ylabel('C_{eff}');
set(gca,'YScale','log');
yyaxis right
plot(ncArr, nbarSS);
ylabel('\langle n \rangle');
set(gca,'YScale','log');
set(gca,'XScale','log');
xlabel('n_c (photons)');
xlim([min(ncArr) max(ncArr)]);
yyaxis left
hr = refline(0,1);
hr.Color = 'b';
hr.LineStyle = ':';

% Ceff sensitivity analysis
NumX = 20;
NumY = 20;
CeffStudy = zeros(NumX,NumY);
CeffArr = zeros(1,numNC);
gammaOMperPhotonArr = linspace(5.0e2, 3.0e4, NumX);
nP1Arr = logspace(-1,2,NumX);
for gg = 1:NumX
    for nn = 1:NumY
        CeffArr(1,:) = gammaOMperPhotonArr(gg).*ncArr./(gammaP.*(nP1Arr(nn).*ncArr.^(alphanP)+1) + gamma0.*(n0+1));
        CeffStudy(gg,nn) = max(CeffArr);
        CeffArr = zeros(1,1e4);
    end
end
% figure();
% colormap hot
% caxis(log([min(min(CeffStudy)) max(max(CeffStudy))]));
% surf(nP1Arr, gammaOMperPhotonArr, log(CeffStudy),'LineStyle','none');
% %set(gca,'ZScale','log');
% set(gca,'YScale','log');
% set(gca,'XScale','log');
% ylim([min(gammaOMperPhotonArr) max(gammaOMperPhotonArr)]);
% %zlim([min(min(CeffStudy)) max(max(CeffStudy))]);
% xlabel('n_P(n_c = 1) [single-photon bath occupancy]');
% ylabel('\gamma_{OM}/n_c (Hz)');
% zlabel('log(Max(C_{eff}))');
% colorbar;

%% Pulsed measurements

% laser power level
Pin0dB = 40.0e-6; % W, into circulator port 1
Pin = Pin0dB*eta12*etaCpl*eta2F;

ncOn = 50;
ncOff = ncOn*10^(-0.1*(ExtRatio));

gammaPon = gammaPhandle(ncOn);
gammaPoff = gammaPhandle(ncOff);

Npulses = 1e3; % number of pulses to simulate
Tper = 1.0e-3; % s, pulse period
Tpulse = 10.0e-6; % s, pulse length
Toff = Tper - Tpulse;

nZero = n0; % initial occupancy at start of pulse train

% time domain for solving
dt = Tpulse/100;
Dt = Npulses*Tper;
Nt = ceil(Dt/dt);
tArr = linspace(0, Npulses*Tper, Nt);
for n = 1:Npulses
    
end


%% END



