% Matlab file to estimate mechanical mode occupancy in mK experiments
% 
% Written by Oskar Painter, 11/30/13

% h=gcf;
% axesObjs = get(h, 'Children');  %axes handles
% dataObjs = get(axesObjs, 'Children'); %handles to low-level graphics objects in axes
% xdata = get(dataObjs, 'XData');  %data from low-level grahics objects
% ydata = get(dataObjs, 'YData');

format long;

c=3e8; % speed of light in m/s
hbar=6.626e-34/2/pi; % quantum unit (J s)
kB=1.3806488e-23; % Boltzmann constant (J/K)
eps_o=8.85e-12; % permitiivity of free-space (F/m)
q_e = 1.602e-19; % magnitude of charge of an electron (C)
n_Si=3.45; % refractive index of Si
n_SiNx=2; % refractive index of SiNx
n_eff=2.8; % effective index of WGM modes (TM)
m_o = 9.1095e-31; % mass of a bare electron (kg)
m_ch = 0.39*m_o; % conductive effective hole mass (kg)
m_ce = 0.26*m_o; % conductive effective hole mass (kg)
mu_h = 410e-4; % hole mobility in m^2/V/s (good for N_A <= 10^16 cm^-3)
mu_e = 1300e-4; % electron mobility in m^2/V/s (good for N_D <= 10^16 cm^-3)

omega_m = 2*pi*5.3e9; % mechanical mode frequency (rad/s)
xzpf = 5e-15; % zpf of mechanical mode (m)
w_b = 500e-9; % beam width in (m)
t_b = 220e-9; % beam thickness (m)
L_b = 20e-6; % beam length (m)
w_m = 500e-9; % beam width in (m)
t_m = 220e-9; % beam thickness (m)
L_m = 5e-6; % beam length (m)
lambda_op = 1540e-9; % optical resonance wavelength (m)
omega_op = 2*pi*c/lambda_op; % optical resonance frequency (rad/s)
%Q_c = 2.2e5; % optical resonance loaded Q-factor
Q_op = omega_op/(2*pi*660e6); % optical resonance loaded Q-factor
fudge=0; % dB
det = -1; % pump detuning, +1=red, -1=blue
delta = det.*(omega_m); % cavity-laser detuning


% fridge thermal bath
Qmi = omega_m./(2*pi*0.12);%3.8e10; % intrinsic mechanical Q-factor
gamma_o = (omega_m./Qmi)./(2*pi); % intrinsic mechanical damping of fridge thermal bath (Hz)
Tf_3 = 55e-3; % fridge temperature #3 (K)
nf_3 = 1./(exp(hbar.*omega_m./(kB.*Tf_3))-1); % fridge occupancy #3

% TS in Si
Delta0=(1e-3)*kB; % tunneling energy (J); any value < 20mK works
Delta1=(2e0)*kB; % Gassian distribution width (around zero energy) for asymmetry energy of TLS (J) --> for small Delta0 this basically sets the max energy scale of the TLS involved!
% any value > 1K works

% phonons in Si
ff = 0.5; % filling fraction of 2D plate due to device patterning
v_l = 8.4e3; % [100] Si phonon wave velocity for longtitudinal waves (m/s)
v_t = 5.8e3; % [100] Si phonon wave velocity for transverse or shear waves (m/s)
v_f = v_t;  %approximate velocity for flexural modes

rho_Si = 2.329e3; % Si mass density kg/m^3

% Deformation potentials
% M = (Delta0/E)*gamma
% D = (2*Delta/E)*gamma
% both are on scale of ~ eV
% for Si D~M~0.4eV from thermal conductivity measurements
% Phillips uses Delta0/kB=1mK and gamma = 5eV values
% TLS params
M=1*(0.4)*q_e; % deformation potential for change in tunneling energy versus strain (J)
D=1*(0.4)*q_e; % deformation potential for change in asymmetry energy versus strain (J)
% TS params
gamma_l = 1*(1.6)*q_e; % longt. phonon coupling constant (J) from Phillips, Rep. Prog. Phys. 50 (1987)
gamma_t = 1*(1.0)*q_e; % tran. phonon coupling constant (J) from Phillips, Rep. Prog. Phys. 50 (1987)

% TLS model
% Hint = (sigma_z*D + sigma_x*M)e; in TLS eigenbasis 

% TS model
% Hint = (sigma_z*(Delta/E) + sigma_x*(Delta0/E))e; in TS eigenbasis

% amorphous TLS (a-TLS) distribution function
n0 = (80e30)*1e7*1e6; % density of amorphous TLS per unit volume per unit energy (states/J/m^3), from Kleiman, et al., PRL v59(18) 1987
P = 2*3e44; % density of TS states per unit volume per unit asymmetry energy (states/m^3/J), from Phillips, Rep. Prog. Phys. 50 (1987)
Deltamax = (1000)*kB; % maximum TLS energy (J) from Kleiman, et al., PRL v59(18) 1987
Delta0min = (1e-3)*kB; % minimum  tunneling energy (J)
Delta0max = (5)*kB; % maximum tunneling energy (J)
Delta0 = linspace(Delta0min,Delta0max,1e4); % range of TS tunneling energies (J)
Delta = 10*transpose(linspace(1e-4,1,1e2)); % normalized asymmetry energy vector
Delta02 = (Delta./Delta)*Delta0; % 2D array of TS tunneling energies, with varying tunneling energy in different columns (J)
Delta2 = Delta*Delta0; % 2D array of TS asymmetry energies (J), with varying asymmetry energy in different rows
E2 = (Delta02.^2 + Delta2.^2).^(1/2); % 2D array of TS energies (J)

stepDelta = Delta2(2,:) - Delta2(1,:); % step size of TS asymmetry energy (J) [column vector of length Delta0]
stepDelta0 = (Delta02(1,2) - Delta02(1,1)).*(Delta0./Delta0); % step size for TS tunneling energy (J) [single step size used for Delta0; column vector of length Delta0]

T = (linspace(10e-3,1,1e2)); % temperature (K)

% structure properties
amorphSiOx_th = 0.25e-9; % SiO2 thickness is ~ 0.25nm after HF cleaning and ultrapure water cleaning...amorphous layer thickness (nm)
sidewalldamage_th = 15e-9; % sidewall damage layer thickness (nm)
surf_fract = (2*amorphSiOx_th./t_b)+(4*sidewalldamage_th./w_b); % density factor that accounts for small fractional volume that is amorphous
n0eff = n0.*surf_fract; % effective amorphous TLS density (states/J/m^3)
Peff = P.*surf_fract; % effective amorphous TS density (states/J/m^3)
fTS2 = Peff./Delta02; % TS density distribution in (Delta0,Delta) space (states/J/m^3)
N0a = n0.*surf_fract.*(Deltamax) % total number of amorphous TLS states/m^3
N0a_tot = N0a.*t_m.*w_m.*L_m % total number of amorphous TLS states interacting with mode
BW = 1e4 % considered bandwidth
N0a_BW = N0a_tot.*(2*pi*BW*hbar)./Deltamax % total number of amorphous TLS states interacting with mode that lie within bandwidth of mode
% phonon DOS and coupling
% assume 2D DOS (per unit volume)
omegacoff = (v_f./(t_b./(12).^(1/2))).^(1); % cut-off frequency for flexural modes in thickness direction of plate (s^(-1))
g2Dl = (2./(pi*t_b))*(E2./(hbar^2*v_l.^2)); % longt. phonon mode density in 2D plate per unit energy per unit volume (J^(-1) m^(-3))
g2Dt = (2./(pi*t_b))*(E2./(hbar^2*v_t.^2)); % shear phonon mode density in 2D plate per unit energy per unit volume (J^(-1) m^(-3))
g2Df = (2./(pi*t_b))*((E2.*(hbar*omegacoff)).^(1/2)./(hbar^2*v_f.^2)); % flexural phonon mode density in 2D plate per unit energy per unit volume (J^(-1) m^(-3))
% 1D DOS (per unit volume)
g1Dl = (1./(pi*t_b*w_b))*(1./(hbar^1*v_l.^1)); % longt. phonon mode density in 1D beam per unit energy per unit volume (J^(-1) m^(-3))
g1Dt = (1./(pi*t_b*w_b))*(1./(hbar^1*v_t.^1)); % torsional phonon mode density in 1D beam per unit energy per unit volume (J^(-1) m^(-3))
g1Df = (1./(pi*t_b*w_b))*(1./(hbar^1*v_f.^1)).*(hbar*omegacoff./E2).^(1/2); % torsional phonon mode density in 1D beam per unit energy per unit volume (J^(-1) m^(-3))

% phonon strain amplitudes
e2Dl = (hbar./(2*rho_Si)).^(1/2).*(1./v_l).*(E2./hbar).^(1/2); % per phonon per unit volume strain for longt. phonon modes (m^(3/2))
e2Dt = (hbar./(2*rho_Si)).^(1/2).*(1./v_t).*(E2./hbar).^(1/2); % per phonon per unit volume strain for shear phonon modes (m^(3/2))
e2Df = (hbar./(2*rho_Si)).^(1/2).*(1./v_f).*(2*(12)^(1/2)).^(-1).*(E2./hbar).^(1/2); % per phonon per unit volume strain for flexural phonon modes (m^(3/2))

% 3-phonon scattering
av_grun = 0.24; % from Gauster, PRB v4(4), 1971; mode averaged Grueneisen's parameter = (delta(omega)/omega)/(delta(V)/V) = -d(ln(omega))/d(ln(V)); av(|A_{qs,q's',q"s"}|^2) = (4\rho^2/av(c)^2)*(c_s^2*c_s'^2*c_s"^2)*avgrun^2 
av_csq = (2*v_t^2 + v_l^2)/3; % average sound velocity squared 
av_Asq_TLL = ((4*rho_Si)./av_csq)*(v_t^2*v_l^2*v_l^2)*av_grun.^2; % average T+L->L 3-phonon scattering amplitude squared (kg^2/m^2/s^4)
av_Asq_LLL = ((4*rho_Si)./av_csq)*(v_l^2*v_l^2*v_l^2)*av_grun.^2; % average L+L->L 3-phonon scattering amplitude squared (kg^2/m^2/s^4)
av_Asq_TTL = ((4*rho_Si)./av_csq)*(v_t^2*v_t^2*v_l^2)*av_grun.^2; % average T+T->L 3-phonon scattering amplitude squared (kg^2/m^2/s^4)
% region of integration 
% 0<x<1; x=q/qD, qD = Debye wavevector, q = wavevector of mode of interest
% class 1 (s+s'->s"), Normal processes: 0,(1-C)x/(1+D) < x' < (1+C)x/(1-D),(1-Cx)/D,1
% class 2 (s->s'+s"), Normal processes: 0,(2-(1+C)x)/(1+D) < x' < (1-Cx)/D,1
% C = c_s/c_s", D = c_s'/c_s"
r = v_t/v_l;
x1=(1-r)/(1+r);
x2=(1-r)/r;
x3=(1-r)/2;
x4=1-r;
x5=2*r/(1+r);
x6=(1+r)/2;
% class 1 events dominate our phonon bottleneck situation with omega_m <
% omega_c (xc=omega_c/omega_D)
% for our Low T and small wavevector situation we need only consider Normal
% processes
% given ratio of transverse to longtitudinal sound velocities for acoustic
% phonons (Debye model), the following processes will have the following
% range of integration:
% L+L->L: x'=xc,1 (full range)
% T+L->L: x'=xc,1 (full range)
% T+T->L: x'=xc,x/x1 (could be zero range...x/x1->25GHz)
% L+T->L: x'=xc,x/x3 (could also be zero range...x/x3->32GHz)

omega_c = 2*pi*30e9; % cut-off frequency for 3-phonon scattering (rad/s)
xc = (hbar*omega_c)./(kB.*T); % cut-off normalized frequency
xm = (hbar*omega_m)./(kB.*T); % normalized mode frequency
xmax = 10; % maximum normalized frequency to consider (beyond this, there are no phonons to scatter with)
nbarm = (exp(xm)-1).^(-1); % Bose factor for thermal occupancy of mode m
A_3ph = (hbar*omega_m)./(8*pi^2*rho_Si*av_csq).*(av_grun).^2.*(v_l.^4.*(nbarm+1)).^(-1).*(kB.*T./hbar).^(5); % 3-phonon scattering rate coefficient for each temperature (L+L->L)

for m=1:length(T)
   
% TLS damping
% 2D phonon bath
gammaTLS_2Dl(:,:,m) = (2*pi/hbar).*(gamma_l^2).*(Delta02./E2).^2.*(e2Dl.^2.*g2Dl).*coth(E2./(2*kB*T(m))); % TLS damping rate due to longt. phonons (s^(-1))
gammaTLS_2Dt(:,:,m) = (2*pi/hbar).*(gamma_t^2).*(Delta02./E2).^2.*(e2Dt.^2.*g2Dt).*coth(E2./(2*kB*T(m))); % TLS damping rate due to trans. phonons (s^(-1))
gammaTLS_2Df(:,:,m) = (2*pi/hbar).*(gamma_t^2).*(Delta02./E2).^2.*(e2Df.^2.*g2Df).*coth(E2./(2*kB*T(m))); % TLS damping rate due to flexural phonons (s^(-1))
% phonon damping
gammaph_2Dl(m) = ((gamma_l).^2./(4*rho_Si*v_t^2*kB.*T(m))).*(dot((sum((Delta2./E2).^2.*fTS2.*gammaTLS_2Dl(:,:,m).*(sech(E2./(2*kB.*T(m)))).^2,1).*stepDelta),stepDelta0)); % phonon damping rate due to non-res relaxation damping from TLS coupled to longt. mode phonons (s^(-1))
gammaph_2Dt(m) = ((gamma_t).^2./(4*rho_Si*v_t^2*kB.*T(m))).*(dot((sum((Delta2./E2).^2.*fTS2.*gammaTLS_2Dt(:,:,m).*(sech(E2./(2*kB.*T(m)))).^2,1).*stepDelta),stepDelta0)); % phonon damping rate due to non-res relaxation damping from TLS coupled to tran. mode phonons (s^(-1))
gammaph_2Df(m) = ((gamma_t).^2./(4*rho_Si*v_t^2*kB.*T(m))).*(dot((sum((Delta2./E2).^2.*fTS2.*gammaTLS_2Df(:,:,m).*(sech(E2./(2*kB.*T(m)))).^2,1).*stepDelta),stepDelta0)); % phonon damping rate due to non-res relaxation damping from TLS coupled to flexural mode phonons (s^(-1))
gammaph_2Dtot(m) = gammaph_2Dl(m) + gammaph_2Dt(m) + gammaph_2Df(m); % total phonon damping rate due to non-res relaxation from TLS coupled to a 2D bath of phonons (s^(-1))

% 1D phonon bath
gammaTLS_1Dl(:,:,m) = (2*pi/hbar).*(gamma_l^2).*(Delta02./E2).^2.*(e2Dl.^2.*g1Dl).*coth(E2./(2*kB*T(m))); % TLS damping rate due to longt. phonons (s^(-1))
gammaTLS_1Dt(:,:,m) = (2*pi/hbar).*(gamma_t^2).*(Delta02./E2).^2.*(e2Dt.^2.*g1Dt).*coth(E2./(2*kB*T(m))); % TLS damping rate due to trans. phonons (s^(-1))
gammaTLS_1Df(:,:,m) = (2*pi/hbar).*(gamma_t^2).*(Delta02./E2).^2.*(e2Df.^2.*g1Df).*coth(E2./(2*kB*T(m))); % TLS damping rate due to flexural phonons (s^(-1))
% phonon damping
gammaph_1Dl(m) = ((gamma_l).^2./(4*rho_Si*v_t^2*kB.*T(m))).*(dot((sum((Delta2./E2).^2.*fTS2.*gammaTLS_1Dl(:,:,m).*(sech(E2./(2*kB.*T(m)))).^2,1).*stepDelta),stepDelta0)); % phonon damping rate due to non-res relaxation damping from TLS coupled to longt. mode phonons (s^(-1))
gammaph_1Dt(m) = ((gamma_t).^2./(4*rho_Si*v_t^2*kB.*T(m))).*(dot((sum((Delta2./E2).^2.*fTS2.*gammaTLS_1Dt(:,:,m).*(sech(E2./(2*kB.*T(m)))).^2,1).*stepDelta),stepDelta0)); % phonon damping rate due to non-res relaxation damping from TLS coupled to tran. mode phonons (s^(-1))
gammaph_1Df(m) = ((gamma_t).^2./(4*rho_Si*v_t^2*kB.*T(m))).*(dot((sum((Delta2./E2).^2.*fTS2.*gammaTLS_1Df(:,:,m).*(sech(E2./(2*kB.*T(m)))).^2,1).*stepDelta),stepDelta0)); % phonon damping rate due to non-res relaxation damping from TLS coupled to flexural mode phonons (s^(-1))
gammaph_1Dtot(m) = gammaph_1Dl(m) + gammaph_1Dt(m) + gammaph_1Df(m); % total phonon damping rate due to non-res relaxation from TLS coupled to a 1D bath of phonons (s^(-1))

% 3-phonon scattering
x = linspace(xc(m),max(xc(m)*xmax,xmax),1e4); % set of normalized frequencies for mode q's' to integrate over
dx = x(2)-x(1); % stepsize in x-space
xpxm = x+xm(m); % set of normalized frequencies for mode q"s"
nbarx = (exp(x)-1).^(-1); % Bose factor for thermal occupancy of mode q's'
nbarxpxm = (exp(xpxm)-1).^(-1); % Bose factor for thermal occupancy of mode q"s"
intx(m) = dx.*(sum(((x.*xpxm).^2).*(nbarx.*(nbarxpxm+1))));% 3-phonon scattering integral for full range interactions (L+L->L and T+L->L)
end

% 3-phonon scattering, cont.
gamma_3ph = A_3ph.*intx; % 3-phonon damping rate, assuming class 1 event of the Normal process type(as opposed to Umklapp?) (rad/s)


%figures

% figure;
% plot(T,gammaph_2Dl./(2*pi),'k--',T,gammaph_2Dt./(2*pi),'r--',T,gammaph_2Df./(2*pi),'g--',T,gammaph_2Dtot./(2*pi),'b-'); 
% title('non-res a-TLS phonon damping rate (2D)','FontSize',16,'VerticalAlignment','bottom')
% ylabel('phonon damping rate (Hz)','FontSize',16,'VerticalAlignment','bottom')
% xlabel('temperature (K)','FontSize',16,'VerticalAlignment','top')
% %legend('0th','p1','m1','p2','m2');
% 
% figure;
% loglog(T,gammaph_2Dl./(2*pi),'k--',T,gammaph_2Dt./(2*pi),'r--',T,gammaph_2Df./(2*pi),'g--',T,gammaph_2Dtot./(2*pi),'b-'); 
% title('non-res a-TLS phonon damping rate (2D)','FontSize',16,'VerticalAlignment','bottom')
% ylabel('phonon damping rate (Hz)','FontSize',16,'VerticalAlignment','bottom')
% xlabel('temperature (K)','FontSize',16,'VerticalAlignment','top')
% %legend('0th','p1','m1','p2','m2');

figure;
plot(T,gammaph_1Dl./(2*pi),'k--',T,gammaph_1Dt./(2*pi),'r--',T,gammaph_1Df./(2*pi),'g--',T,gammaph_1Dtot./(2*pi),'b-'); 
title('non-res a-TLS phonon damping rate (1D)','FontSize',16,'VerticalAlignment','bottom')
ylabel('phonon damping rate (Hz)','FontSize',16,'VerticalAlignment','bottom')
xlabel('temperature (K)','FontSize',16,'VerticalAlignment','top')
%legend('0th','p1','m1','p2','m2');

figure;
loglog(T,gammaph_1Dl./(2*pi),'k--',T,gammaph_1Dt./(2*pi),'r--',T,gammaph_1Df./(2*pi),'g--',T,gammaph_1Dtot./(2*pi),'b-'); 
title('non-res a-TLS phonon damping rate (1D)','FontSize',16,'VerticalAlignment','bottom')
ylabel('phonon damping rate (Hz)','FontSize',16,'VerticalAlignment','bottom')
xlabel('temperature (K)','FontSize',16,'VerticalAlignment','top')
%legend('0th','p1','m1','p2','m2');

figure;
plot(T,gamma_3ph./(2*pi),'k--'); 
title('3-phonon scattering (N, L+L->L)','FontSize',16,'VerticalAlignment','bottom')
ylabel('phonon damping rate (Hz)','FontSize',16,'VerticalAlignment','bottom')
xlabel('temperature (K)','FontSize',16,'VerticalAlignment','top')
%legend('0th','p1','m1','p2','m2');

figure;
loglog(T,gamma_3ph./(2*pi),'k--'); 
title('3-phonon scattering (N, L+L->L)','FontSize',16,'VerticalAlignment','bottom')
ylabel('phonon damping rate (Hz)','FontSize',16,'VerticalAlignment','bottom')
xlabel('temperature (K)','FontSize',16,'VerticalAlignment','top')
%legend('0th','p1','m1','p2','m2');

figure;
plot(T,gamma_3ph./(2*pi),'g-',T,gammaph_1Dtot./(2*pi),'b-',T,(gammaph_1Dtot+gamma_3ph)./(2*pi),'r-'); 
title('phonon damping versus Temp','FontSize',16,'VerticalAlignment','bottom')
ylabel('phonon damping rate (Hz)','FontSize',16,'VerticalAlignment','bottom')
xlabel('temperature (K)','FontSize',16,'VerticalAlignment','top')
%legend('0th','p1','m1','p2','m2');

figure;
loglog(T,gamma_3ph./(2*pi),'g-',T,gammaph_1Dtot./(2*pi),'b-',T,(gammaph_1Dtot+gamma_3ph)./(2*pi),'r-'); 
title('phonon damping versus Temp','FontSize',16,'VerticalAlignment','bottom')
ylabel('phonon damping rate (Hz)','FontSize',16,'VerticalAlignment','bottom')
xlabel('temperature (K)','FontSize',16,'VerticalAlignment','top')
%legend('0th','p1','m1','p2','m2');