% Matlab file to estimate mechanical mode occupancy in mK experiments
% 
% Written by Oskar Painter, 11/30/13
% Modified by Greg MacCabe, 09/12/2017
%
function [ton nbarton] = OMC_nbarton_eval(Tf_3, Acoeff);

% function evaluates nbarton (occupancy during on pulse)
% INPUTS: 
%       Tf: base fridge temperature *to which the mode really thermalizes in the
%       dark* (K)
%       Acoeff: const. of order 1. Coefficient for Ab (K)
%
% OUTPUTS:
%       ton: 1 x numT array of time points
%       nbarton: 1 x numT array of mode occupancy during on-state
%   

    c=3e8; % speed of light in m/s
    hbar=6.626e-34/2/pi; % quantum unit (J s)
    kB=1.3806488e-23; % Boltzmann constant (J/K)
    eps_o=8.85e-12; % permitiivity of free-space (F/m)
    q_e = 1.602e-19; % magnitude of charge of an electron (C)
    n_Si=3.45; % refractive index of Si
    n_SiNx=2; % refractive index of SiNx
    n_eff=2.8; % effective index of WGM modes (TM)
    m_o = 9.1095e-31; % mass of a bare electron (kg)
    m_ch = 0.39*m_o; % conductive effective hole mass (kg)
    m_ce = 0.26*m_o; % conductive effective hole mass (kg)
    mu_h = 410e-4; % hole mobility in m^2/V/s (good for N_A <= 10^16 cm^-3)
    mu_e = 1300e-4; % electron mobility in m^2/V/s (good for N_D <= 10^16 cm^-3)

    omega_m = 2*pi*5.0525e9; % mechanical mode frequency (rad/s)
    lambda_c = 1541.850e-9; % optical resonance wavelength (m)
    omega_c = 2*pi*c/lambda_c; % optical resonance frequency (rad/s)
    %Q_c = 2.2e5; % optical resonance loaded Q-factor
    Q_c = omega_c/(2*pi*1.507e9); % optical resonance loaded Q-factor
    fudge=0; % dB
    det = 1; % pump detuning, +1=red, -1=blue

    % optical pulse definition
    numT = 1e5; % number of time series points to compute
    ncpulseon=10.03;%320; % steady-state pulse 'on' amplitude in intra-cavity photon number
    modrt=5.37e-9; % modulator rise 1/e time (s) 
    agrt=300e-9; % agiltron rise time (s)
    modft=modrt; % modulator fall time (s)
    agft=30e-6; % agiltron fall time (s)
    % pextmod = 10^(-(27.5+20)/10); % modulator extinction of on pulse during off pulse
    % pextag = 10^(-(15+20)/10); % agiltron extinction of on pulse during off pulse
    pextmod = 10^(-(27.5+20)/10); % modulator extinction of on pulse during off pulse
    pextag = 10^(-(15+20)/10); % agiltron extinction of on pulse during off pulse
    ncpulseoff=ncpulseon.*pextmod.*pextag; % steady-state pulse 'off' amplitude in intra-cavity photon number
    %tsson=1.25/ongamma; % estimated time to steady-state for on-pulse, (s)
    %tssoff=7/offgamma; % estimated time to steady-state for off-pulse, (s)
    tsson=10e-6;%0.6e-6;%3.0e-6; % on-pulse width, (s)
    tssoff=5e-3;%5e-3;%333.0e-6; % off-pulse width, (s)
    ton=linspace(0,tsson,numT); % time series to compute
    toff=logspace(-8,log10(tssoff),1e6); % time series to compute
    tonagoffset = -2e-6; % agiltron turn-on offset (s)
    Tmodon=pextmod.*exp(-ton./modrt) + 1.*(1-exp(-ton./modrt)); % modulator transmission during on pulse (%)
    Tagon=pextag.*exp(-(ton-tonagoffset)./agrt) + 1.*(1-exp(-(ton-tonagoffset)./agrt)); % agiltron transmission during on pulse (%)
    Tmodoff=1.*exp(-toff./modft) + pextmod.*(1-exp(-toff./modft)); % modulator transmission during off pulse (%)
    Tagoff=1.*exp(-toff./agft) + pextag.*(1-exp(-toff./agft)); % agiltron transmission during off pulse (%)
    ncon=ncpulseon.*Tmodon.*Tagon; % nc during on pulse; Note: neglects finite ring up time of cavity
    ncoff=ncpulseon.*Tmodoff.*Tagoff; % nc during off pulse; Note: neglects finite ring up time of cavity
    tinit=50e-9;%5.2*6/6*modrt; % time taken corresponding to n_i in data set (s)

    % ncon=ncpulseon.*(exp(-ton./modrt).*exp(-ton./agrt) + ncpulseon.*(1-exp(-ton./modrt).*exp(-ton./agrt)); % nc during on pulse; Note: neglects finite ring up time of cavity
    % ncoff=ncpulseon.*(1 - exp(-toff./modft).*exp(-toff./agft) + ncpulseoff.*(1-exp(-toff./modft).*exp(-toff./agft)); % nc during off pulse; Note: neglects finite ring up time of cavity


    % optical laser cooling
    %go = 650e3; % zero-point optomechanical coupling (Hz)
    go = 713e3;%833e3;%713e3; % zero-point optomechanical coupling (Hz)
    kappa = omega_c/(2*pi)/Q_c; % optical cavity linewidth (Hz)
    detfudge = 0*kappa/2*(det+1)/2 + 0.0*0.25*kappa/2*(det-1)/(-2); % detuning from optimal (Hz)
    %gamma_OM = 4.*n_c.*go.^2.*kappa./(kappa^2+4*detfudge^2*(det+1)/(2)); % optomechanical damping (Hz)
    gammaOMon = 4.*ncon.*go.^2.*kappa./(kappa^2+4*detfudge^2); % optomechanical damping during on pulse (Hz) 
    gammaOMoff = 4.*ncoff.*go.^2.*kappa./(kappa^2+4*detfudge^2); % optomechanical damping during off pulse (Hz) 

    % fridge thermal bath
    Qmi = 5.05e9./14.4e3;%3.8e10; % intrinsic mechanical Q-factor
    gamma_o = (omega_m./Qmi)./(2*pi); % intrinsic mechanical damping of fridge thermal bath (Hz)
    %Tf_3 = 40e-3; % fridge temperature #3 (K)
    nf_3 = 1./(exp(hbar.*omega_m./(kB.*Tf_3))-1); % fridge occupancy #3

    % optically induced bath steady-state
    % np=6 at nc=1; --> Tp = 1.5K at nc=1; np=65 at nc=320; --> Tp=15.13K at nc=320
    % gammap=900Hz at nc=1 (Tp=1.5K); --> A_gamma = 1.85e3; gammap=8e4Hz at nc=320 (Tp=15.13K)

    B=1/3; % optical heating exponent for mode occupancy
    A=(Acoeff)*2.0636;%(0.95*18)./(ncon(length(ncon))^B);%3.2;% optical heating constant coeff. (K)
    Tpon = A.*ncon.^(B); % steady-state bath temperature of high frequency phonons created during optical absorption as a function of intra-cavity photon number during on-pulse (K)
    Tpoff = A.*ncoff.^(B); % steady-state bath temperature of high frequency phonons created during optical absorption as a function of intra-cavity photon number during off-pulse (K)

    exp_factor_on = exp(-(hbar.*omega_m./(kB.*Tpon)));
    bose_factor_on = exp_factor_on./(1-exp_factor_on.^(+1)); % bath Bose factor at mode frequency
    exp_factor_off = exp(-(hbar.*omega_m./(kB.*Tpoff)));
    bose_factor_off = exp_factor_off./(1-exp_factor_off.^(+1)); % bath Bose factor at mode frequency

    % optically induced bath mechanical damping (gamma_p)
    B_gamma = 3; % optical heating constant for mode damping
    A_gamma = 1.25738e3;%(0.85*100e3)./(1 - exp_factor_on(length(Tpon)))./(Tpon(length(Tpon)).^(B_gamma));%(0.5)*1.85e3;%3.5;% optically induced mechanical damping const. (Hz) --> affects ringing in occupancy ratio during off pulse
    gammacsson = A_gamma.*(1 - exp_factor_on).*Tpon.^(B_gamma); % steady-state total optically induced mechanical damping as a function of intra-cavity photon number during on-pulse (Hz)
    gammacssoff = A_gamma.*(1 - exp_factor_off).*Tpoff.^(B_gamma); % steady-state total optically induced mechanical damping as a function of intra-cavity photon number during off-pulse (Hz)%

    % optically induced bath effective occupancy (n_p)
    nbarcsson = bose_factor_on; % steady-state high frequency phonon bath occupancy at mechanical mode frequency as a function of intra-cavity photon number during on-pulse
    nbarcssoff = bose_factor_off; % steady-state high frequency phonon bath occupancy at mechanical mode frequency as a function of intra-cavity photon number during off-pulse

    % optically induced bath transient
    FBF = 0.65;%0.65;% 0.25; % fast bath fraction (FBF) --> sensitively controls the overall peak occupancy ratio
    SBF = 1 - FBF; % slow bath fraction (SBF)
    Bbath = 1; % bath nonlinear decay exponent for slow bath
    Bpmode = 1; % mode decay exponent associated with interactions with bath
    %taubath = 10e-3; % initial decay time of slow bath (s)...where decay begins
    %npoff_peak = 14; % maximum bath occupancy during off pulse before decay (quanta)
    bathdecayFon = (50)*2*pi*1e6; % bath decay rate during on pulse for FBF (2*pi*Hz) --> controls early time occupancy, specifically how far the mode cooling curve "dips"
    bathdecaySon = (3)*2*pi*1e5; %(6) % bath decay rate during on pulse for SBF (2*pi*Hz) --> controls rate at which mode occupancy recovers after dip to its ss value
    bathdecayFoff = (2.65)*2*pi*4e4; % bath decay rate during off pulse for FBF (2*pi*Hz) --> controls early time peak occupancy ratio during off pulse
    %bathdecaySoff = (1)./taubath./npoff_peak.^(Bbath-1); % initial bath decay rate during off pulse for SBF (2*pi*Hz/phonon)
    bathdecaySoff = (1.5)*2*pi*4e4; % initial bath decay rate during off pulse for SBF (2*pi*Hz/phonon) --> controls location in time of the peak occupancy ratio during off pulse
    % --> also very sensitively controls the overall max ratio...if too fast
    % then it drops the ratio

    nbathdecayFon=(1)*bathdecayFon;
    nbathdecaySon=(1)*bathdecaySon;
    nbathdecayFoff=(0.6)*bathdecayFoff;
    nbathdecaySoff=(0.6)*bathdecaySoff;

    gbathdecayFon=(1)*bathdecayFon;
    gbathdecaySon=(1)*bathdecaySon;
    gbathdecayFoff=(1.4)*bathdecayFoff;
    gbathdecaySoff=(1.4)*bathdecaySoff;

    % Transient Analysis
    dton = [ton(1),diff(ton)]; % time step during on pulse (s)
    dtoff = [toff(1),diff(toff)]; % time step during off pulse (s)

    nbarinit = nf_3; % initial mode occupancy
    nbarcs_init = 0; % initial slow bath occupancy
    gammacs_init = 0; % initial slow bath coupling rate (Hz)
    nbarcf_init = 0; % initial fast bath occupancy
    gammacf_init = 0; % initial fast bath coupling rate (Hz)

    nbarton(1) = nbarinit;
    nbar_cf_on(1) = nbarcf_init;
    gamma_cf_on(1) = gammacf_init;
    nbar_cs_on(1) = nbarcs_init;
    gamma_cs_on(1) = gammacs_init;

    for m=2:length(ton)
        gamma_cf_on(m) = gamma_cf_on(m-1) - gbathdecayFon.*(gamma_cf_on(m-1) - FBF.*gammacsson(m-1)).*(dton(m)); % fast bath damping rate versus time during on pulse (Hz)
        nbar_cf_on(m) = nbar_cf_on(m-1) - nbathdecayFon.*(nbar_cf_on(m-1) - FBF.*nbarcsson(m-1)).*(dton(m)); % fast bath occupancy versus time during on pulse
        gamma_cs_on(m) = gamma_cs_on(m-1) - gbathdecaySon.*(gamma_cs_on(m-1) - SBF.*gammacsson(m-1)).*(dton(m)); % slow bath damping rate versus time during on pulse (Hz)
        nbar_cs_on(m) = nbar_cs_on(m-1) - nbathdecaySon.*(nbar_cs_on(m-1) - SBF.*nbarcsson(m-1)).*(dton(m)); % slow bath occupancy versus time during on pulse
        gammatoton=2*pi*(gammaOMon(m).*det+gamma_o+gamma_cf_on(m)+gamma_cs_on(m)); % total decay rate of mechanical system during optical during on pulse (2*pi*Hz)
        nbarton(m) = nbarton(m-1) + (-nbarton(m-1).*gammatoton + ((nbar_cs_on(m-1) + nbar_cf_on(m-1)).*(gamma_cs_on(m-1) + gamma_cf_on(m-1)).*2*pi + nf_3.*gamma_o.*2*pi + (1).*((det-1)./(-2).*(gammaOMon(m-1))).*2*pi)).*(dton(m)); % mode occupancy versus time during on pulse 
    end

    nbarcs_init = nbar_cs_on(length(ton)); % initial slow bath occupancy
    nbarcf_init = nbar_cf_on(length(ton)); % initial fast bath occupancy
    gammacs_init = gamma_cs_on(length(ton)); % initial slow bath coupling rate (Hz)
    gammacf_init = gamma_cf_on(length(ton)); % initial fast bath coupling rate (Hz)
    nbarinit=nbarton(length(ton)); % new initial value

    nbartoff(1) = nbarinit;
    nbar_cs_off(1) = nbarcs_init;
    gamma_cs_off(1) = gammacs_init;
    nbar_cf_off(1) = nbarcf_init;
    gamma_cf_off(1) = gammacf_init;

    for m=2:length(toff)
        gamma_cf_off(m) = gamma_cf_off(m-1) - gbathdecayFoff.*(gamma_cf_off(m-1) - FBF.*gammacssoff(m-1)).*(dtoff(m)); % fast bath damping rate versus time during off pulse (Hz)
        nbar_cf_off(m) = nbar_cf_off(m-1) - nbathdecayFoff.*(nbar_cf_off(m-1) - FBF.*nbarcssoff(m-1)).*(dtoff(m)); % fast bath occupancy versus time during off pulse
        gamma_cs_off(m) = gamma_cs_off(m-1) - gbathdecaySoff.*(nbar_cs_off(m-1)).^(Bbath-1).*(gamma_cs_off(m-1) - SBF.*gammacssoff(m-1)).*(dtoff(m)); % slow bath damping rate versus time during off pulse (Hz)
        nbar_cs_off(m) = nbar_cs_off(m-1) - nbathdecaySoff.*(nbar_cs_off(m-1)).^(Bbath-1).*(nbar_cs_off(m-1) - SBF.*nbarcssoff(m-1)).*(dtoff(m)); % slow bath occupancy versus time during off pulse
        gammatotoff=2*pi*(gammaOMoff(m).*det+gamma_o+gamma_cf_off(m)+gamma_cs_off(m)); % total decay rate of mechanical system during optical during off pulse (2*pi*Hz)
        nbartoff(m) = nbartoff(m-1) + (-nbartoff(m-1).*gammatotoff + ((nbar_cs_off(m-1) + nbar_cf_off(m-1)).*(gamma_cs_off(m-1) + gamma_cf_off(m-1)).*2*pi + nf_3.*gamma_o.*2*pi + (1).*((det-1)./(-2).*(gammaOMoff(m-1))).*2*pi)).*(dtoff(m)); % mode occupancy versus time with pulse off
    end

    nbartot=[nbarton,nbartoff]; % initial pulse seequence
    ttot=[ton,ton(length(ton)) + toff]; % initial pulse sequence
    nprobe=[ncon,ncoff]; % optical probe pulse as a function of time for one period (units of intra-cavity photons)


    % gamma_c_off = gammac_init.*SBF.*(exp(-bathdecaygoff.*toff)) + gamma_c(ncindex2).*(1-SBF.*exp(-bathdecaygoff.*toff)); % bath damping rate (Hz) versus time during pulse off due to finite decay rate of bath
    % nbar_c_off = nbarc_init.*SBF.*(exp(-bathdecaynoff.*toff)) + nbar_c(ncindex2).*(1-SBF.*exp(-bathdecaynoff.*toff)); % bath occupancy versus time during pulse off due to finite decay rate of bath


    % pulse series

    N=10; % number of pulse sequences

    nbarinit = nbartoff(length(toff)); % initial mode occupancy
    nbarcf_init = nbar_cf_off(length(toff)); % initial fast bath occupancy
    gammacf_init = gamma_cf_off(length(toff)); % initial fast bath coupling rate (Hz)
    nbarcs_init = nbar_cs_off(length(toff)); % initial slow bath occupancy
    gammacs_init = gamma_cs_off(length(toff)); % initial slow bath coupling rate (Hz)

    for j=1:N
        % on-pulse sequence
        nbarton(1) = nbarinit;
        nbar_cs_on(1) = nbarcs_init;
        gamma_cs_on(1) = gammacs_init;
        nbar_cf_on(1) = nbarcf_init;
        gamma_cf_on(1) = gammacf_init;
        for m=2:length(ton)
           gamma_cf_on(m) = gamma_cf_on(m-1) - gbathdecayFon.*(gamma_cf_on(m-1) - FBF.*gammacsson(m-1)).*(dton(m)); % fast bath damping rate versus time during on pulse (Hz)
           nbar_cf_on(m) = nbar_cf_on(m-1) - nbathdecayFon.*(nbar_cf_on(m-1) - FBF.*nbarcsson(m-1)).*(dton(m)); % fast bath occupancy versus time during on pulse
           gamma_cs_on(m) = gamma_cs_on(m-1) - gbathdecaySon.*(gamma_cs_on(m-1) - SBF.*gammacsson(m-1)).*(dton(m)); % slow bath damping rate versus time during on pulse (Hz)
           nbar_cs_on(m) = nbar_cs_on(m-1) - nbathdecaySon.*(nbar_cs_on(m-1) - SBF.*nbarcsson(m-1)).*(dton(m)); % slow bath occupancy versus time during on pulse
           gammatoton=2*pi*(gammaOMon(m).*det+gamma_o+gamma_cs_on(m)+gamma_cf_on(m)); % total decay rate of mechanical system during optical during on pulse (2*pi*Hz)
           nbarton(m) = nbarton(m-1) + (-nbarton(m-1).*gammatoton + ((nbar_cs_on(m-1)+nbar_cf_on(m-1)).*(gamma_cs_on(m-1)+gamma_cf_on(m-1)).*2*pi + nf_3.*gamma_o.*2*pi + (1).*((det-1)./(-2).*(gammaOMon(m-1))).*2*pi)).*(dton(m)); % mode occupancy versus time during on pulse 
        end

    end

end